@@ -1,4 +1,4 @@
-__version__ = '0.0.50'  # print(ultralytics.__version__)
+__version__ = '0.0.51'  # print(ultralytics.__version__)
 
 
 def checks(verbose=True):
@@ -32,13 +32,13 @@ def checks(verbose=True):
     print(emojis(f'Setup complete ✅ {s}'))
 
 
-def login():
+def login(api_key=''):
     # Login to Ultralytics HUB
     from .main import connect_to_hub
-    connect_to_hub(verbose=True)
+    connect_to_hub(api_key, verbose=True)
 
 
-def start():
+def start(api_key=''):
     # Start training models with Ultralytics HUB
     from .main import train_model
-    train_model()
+    train_model(api_key)
