@@ -58,10 +58,11 @@ class Auth:
             self.secure_token = r.json()
             self.id_token = self.secure_token.get("idToken")
 
-    def attempt_api_key(self, attempts=1):
-        s = f'. Attempt {attempts} of 3' if attempts > 1 else ' from https://hub.ultralytics.com/settings/api-keys'
-        print(PREFIX, end='')
-        api_key = getpass.getpass(f"Enter API key{s}: ")
+    def attempt_api_key(self, attempts=1, api_key=''):
+        if not api_key:
+            s = f'. Attempt {attempts} of 3' if attempts > 1 else ' from https://hub.ultralytics.com/settings/api-keys'
+            print(PREFIX, end='')
+            api_key = getpass.getpass(f"Enter API key{s}: ")
         self.validate_api_key(api_key)
         if not self.api_key:
             attempts += 1
